==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>正在检查，即将完成，感谢您耐心等待</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>正在准备</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>检查到一些错误</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>进入桌面</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>欢迎您，系统已成功升级</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>当前版本：</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>查看日志</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>更新成功</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>您的电脑即将重启 %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>您的电脑即将关机 %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>未能自动完成重启操作，请尝试手动重启您的设备。</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>未能自动完成关机操作，请尝试手动关闭您的设备。</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>收起日志</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>更新失败</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>备份失败</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>系统无法备份，继续升级，系统将无法回退</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>磁盘空间不足，请清理磁盘后再更新</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>无法启动备份服务，请检查后重试</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>无法启动更新服务，请检查后重试</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>依赖错误</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg错误</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>重新备份</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>退出更新</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>继续更新</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>进入桌面</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>正在准备更新...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>更新时请勿强制关机或断电，否则会导致系统损坏</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.21.tar.xz: BUILD/src/dde-update/translations/dde-update_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>正在检查，即将完成，感谢您耐心等待</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>正在准备</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>检查到一些错误</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>进入桌面</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>欢迎您，系统已成功升级</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>当前版本：</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>更新成功</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>您的电脑即将重启 %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>您的电脑即将关机 %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>未能自动完成重启操作，请尝试手动重启您的设备。</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>未能自动完成关机操作，请尝试手动关闭您的设备。</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>查看更新日志</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>收起更新日志</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>日志已导出至桌面</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>日志导出失败, 请重试尝试</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>更新失败</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>备份失败</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>系统无法备份，继续升级，系统将无法回退</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>磁盘空间不足，请清理磁盘后再更新</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>无法启动备份服务，请检查后重试</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>无法启动更新服务，请检查后重试</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>依赖错误</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg错误</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>重新备份</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>退出更新</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>继续更新</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>进入桌面</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>正在准备更新...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>更新时请勿强制关机或断电，否则会导致系统损坏</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>查看更新日志</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>收起更新日志</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>更新日志</translation>
    </message>
</context>
</TS>
